@@ -27,58 +27,61 @@ class Orden(BaseModel):
         types.TopologiaOrdenPago.notify_on_payment_settlement
     )
     op_usu_clave: str
-
+    # checksum
     op_firma_dig: str
-
+    # origin info
     op_nom_ord: str = None
     op_tc_clave_ord: types.TipoCuentaOrdenPago = None
     op_cuenta_ord: str = None
     op_rfc_curp_ord: str = None
     op_ins_clave_ord: digits(3, 5) = types.ClaveOrdenanteOrdenPago.AMU
-
+    # destination info
     op_nom_ben: str = None
     op_tc_clave_ben: types.TipoCuentaOrdenPago = None
     op_cuenta_ben: str = None
     op_rfc_curp_ben: str = None
     op_ins_clave_ben: digits(3, 5) = None
-
+    # additional destination info
     op_nom_ben_2: str = None
     op_tc_clave_ben_2: types.TipoCuentaOrdenPago = None
     op_cuenta_ben_2: str = None
     op_rfc_curp_ben_2: str = None
-
+    # concept info
     op_concepto_pago: str = None
     op_concepto_pag_2: str = None
-
+    # additional general info
     op_iva: float = None
     op_ref_numerica: str = None
     op_ref_cobranza: str = None
-
     op_clave_pago: str = None
+    # refunds info
     op_to_clave: int = None
     op_cd_clave: types.TipoDevolucionOrdenPago = None
-
+    # invoice info
     op_info_factura: str = None
-
+    # original info
     op_folio_ori: int = None
     paq_folio_ori: int = None
     op_fecha_oper_ori: int = None
     op_rastreo_ori: str = None
     op_monto_intereses: float = None
     op_monto_ori: float = None
-
+    # beneficiary
     op_indica_ben_rec: int = None
-
+    # codi origin info
     op_num_cel_ord: int = None
     op_digito_ver_ord: int = None
-
+    # codi destination info
+    op_num_cel_ben: int = None
+    op_digito_ver_ben: int = None
+    # codi info
     op_folio_codi: str = None
     op_comision_trans: int = None
     op_monto_comision: float = None
-
+    # codi merchant info
     op_cert_comer_env: int = None
     op_digito_ver_comer: int = None
-
+    # karpay system info
     op_fecha_cap: int = None
     op_folio_servidor: int = None
     op_usu_autoriza: str = None
@@ -107,7 +110,7 @@ class Orden(BaseModel):
 
         raise ValueError('must be in YYYYMMDD format')
 
-    def build_xml(self):
+    def build_xml(self):  # noqa: WPS231
         mensaje = etree.Element('mensaje', categoria=self.categoria)
         ordenpago = etree.SubElement(mensaje, 'ordenpago', Id=str(self.id))
 
@@ -122,6 +125,10 @@ class Orden(BaseModel):
                     subelement = etree.SubElement(ordenpago, 'opFirmaDig')
                     subelement.text = str(value)
                     continue
+                if element == 'op_ins_clave_ben':
+                    subelement = etree.SubElement(ordenpago, 'OpInsClave')
+                    subelement.text = str(value)
+                    continue
                 upper_camel_case_element = to_upper_camel_case(element)
                 subelement = etree.SubElement(ordenpago, upper_camel_case_element)
                 subelement.text = str(value)
